@@ -1,5 +1,7 @@
-""" Functions for correcting raman lidar data. """
+"""
+This module contains functions for correcting raman lidar data
 
+"""
 import numpy as np
 
 
