@@ -1,7 +1,4 @@
 """
-act.qc.qcfilter
-------------------------------
-
 Functions and methods for creating ancillary quality control variables
 and filters (masks) which can be used with various corrections
 routines in ACT.
@@ -10,6 +7,7 @@ routines in ACT.
 
 import numpy as np
 import xarray as xr
+import dask
 
 from act.qc import qctests, comparison_tests
 
@@ -157,12 +155,18 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
 
         # Create the QC variable filled with 0 values matching the
         # shape of data variable.
-        self._obj[qc_var_name] = xr.zeros_like(self._obj[var_name], dtype=np.int32)
-        self._obj[qc_var_name].attrs = {}
-        # This is the way to update the DataArrays in the Dataset to be Dask arrays
-        # instead of Numpy arrays but it's messing things up in a strange way. Maybe
-        # a bug in Xarray? Leave commented out for now.
-#        self._obj = self._obj.chunk()
+        try:
+            qc_data = dask.array.from_array(
+                np.zeros_like(self._obj[var_name].values, dtype=np.int32),
+                chunks=self._obj[var_name].data.chunksize)
+        except AttributeError:
+            qc_data = np.zeros_like(self._obj[var_name].values, dtype=np.int32)
+
+        self._obj[qc_var_name] = xr.DataArray(
+            data=qc_data, dims=self._obj[var_name].dims,
+            attrs={"long_name": qc_variable_long_name,
+                   "units": '1'}
+        )
 
         # Update if using flag_values and don't want 0 to be default value.
         if flag_type and flag_values_set_value != 0:
@@ -170,8 +174,6 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
                 self._obj[qc_var_name].values + int(flag_values_set_value)
 
         # Add requried variable attributes.
-        self._obj[qc_var_name].attrs['long_name'] = qc_variable_long_name
-        self._obj[qc_var_name].attrs['units'] = '1'
         if flag_type:
             self._obj[qc_var_name].attrs['flag_values'] = []
         else:
@@ -292,8 +294,12 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
                 self._obj[qc_var_name].attrs['flag_values'] = [test_number]
         else:
             try:
-                self._obj[qc_var_name].attrs['flag_masks'].append(
-                    set_bit(0, test_number))
+                if isinstance(self._obj[qc_var_name].attrs['flag_masks'], list):
+                    self._obj[qc_var_name].attrs['flag_masks'].append(set_bit(0, test_number))
+                else:
+                    flag_masks = np.append(self._obj[qc_var_name].attrs['flag_masks'],
+                                           set_bit(0, test_number))
+                    self._obj[qc_var_name].attrs['flag_masks'] = flag_masks
             except KeyError:
                 self._obj[qc_var_name].attrs['flag_masks'] = [set_bit(0, test_number)]
 
@@ -468,7 +474,7 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
 
     def available_bit(self, qc_var_name, recycle=False):
         """
-        Method to determine next availble bit or flag to use with a QC test.
+        Method to determine next available bit or flag to use with a QC test.
         Will check for flag_masks first and if not found will check for
         flag_values. This will drive how the next value is chosen.
 
@@ -658,7 +664,6 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
                     fill_value=1e+20, dtype=float32)
 
         """
-
         qc_var_name = self._obj.qcfilter.check_for_ancillary_qc(
             var_name, add_if_missing=False)
 
@@ -739,11 +744,11 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
         """
         Method to apply quality control variables to data variables by
         changing the data values in the dataset using quality control variables.
-        The data variable is changed to to a numpy masked array with failing data
-        masked or, if requested, to numpy array with failing data set to NaN.
-        This can be used to update the data variable in the xarray dataset for use with
-        xarray methods to perform analysis on the data since those methods don't
-        read the quality control variables.
+        The data variable is changed to to a numpy masked array with failing
+        data masked or, if requested, to numpy array with failing data set to
+        NaN. This can be used to update the data variable in the xarray
+        dataset for use with xarray methods to perform analysis on the data
+        since those methods don't read the quality control variables.
 
         Parameters
         ----------
@@ -768,10 +773,10 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
             Opttion to delete quality control variable after processing. Since
             the data values can not be determined after they are set to NaN
             and xarray method processing would also process the quality control
-            variables, the default is to remove the quality control data variables.
-            If numpy masked arrays are used the data are not lost but would need
-            to be extracted and set to DataArray to return the dataset back to orginal state.
-
+            variables, the default is to remove the quality control data
+            variables. If numpy masked arrays are used the data are not lost
+            but would need to be extracted and set to DataArray to return the
+            dataset back to original state.
 
         Examples
         --------
@@ -794,7 +799,6 @@ class QCFilter(qctests.QCTests, comparison_tests.QCTests, object):
                 All data: 98.86097717285156, Bad Removed: 99.15148162841797
 
         """
-
         if variables is not None and isinstance(variables, str):
             variables = [variables]
 
